%{

/*  VT1500 Device Driver for Linux, Version 1.0.10
 *  Copyright (C) 1995-2001  M. Gutschke
 *
 *  At the time of writing my e-mail address is:
 *	Internet: markus@gutschke.com
 *  My snail mail address is:
 *	Markus Gutschke
 *	3637 Fillmore Street #106
 *	San Francisco, CA 94123-1600
 *	USA
 *  If you like this software, I would appreciate if you sent me a postcard
 *  from your hometown. Under the terms of the GNU general public license
 *  you are free to include this program into (commercial) software
 *  distributions (e.g. putting it onto CD-ROM); nonetheless, I would really
 *  appreciate if you dropped me a short note (sending me a sample copy of
 *  your distribution would be even more appreciated!)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdlib.h>

#include "cmds.h"
#include "servlex.h"

%}

%union {
  void     (*fnc)(ParmRec *parmList);
  ParmRec  parmRec;
  ParmRec  *parmList;
  int      iParm;
  char     *sParm;
}

%token <iParm>    NUMBER
%token <sParm>    NAME STRING
%token            AUTHOR WARRANTY CONDITIONS HELP QUIT KILL WARP SNDCMD
%token            SETRADIO SETFRQ SETCHANNEL SETVOLUME SETBASS SETTREBLE
%token            SETMUTE TMPMUTE REFRESHMUTE SETVGA SETTV SETVCR SETPAL
%token            SETNTSC SETHUE SETBRIGHTNESS SETSATURATION SETCONTRAST SETRED
%token            SETGREEN SETBLUE CHANNELNAME ISVISIBLE ISRADIO GETTVVCR
%token            GETPALNTSC GETCHANNEL GETFRQ GETMUTE GETEXTERNALMUTE GETBASS
%token            GETTREBLE GETVOLUME GETINTERNALVOLUME GETEXTERNALVOLUME
%token            GETBRIGHTNESS GETSATURATION GETCONTRAST GETHUE GETRED GETGREEN
%token            GETBLUE CHANNELINFO SETCHANNELINFO CLEARSCREEN SHOWHELP SHOWTVVCR
%token            SHOWMUTE SHOWBASS SHOWTREBLE SHOWVOLUME SHOWCOLOR SHOWCHANNEL

%type  <fnc>      command
%type  <parmList> parms
%type  <parmRec>  parm

%%

serv:	
	|	error ';'			{ yyerrok; }
	|	serv command '(' parms ')' ';'	{ if ($2)
						    $2($4);
						  else
						    serverror("Unknown command"
							      "name");
						  delParms($4); }

command:
		AUTHOR				{ $$ = servAuthor; }
	|	WARRANTY			{ $$ = servWarranty; }
	|	CONDITIONS			{ $$ = servConditions; }
	|	HELP				{ $$ = servHelp; }
	|	QUIT				{ $$ = servQuit; }
	|	KILL				{ $$ = servKill; }
	|	WARP				{ $$ = servWarp; }
	|	SNDCMD				{ $$ = servSndCmd; }
	|	SETRADIO			{ $$ = servSetRadio; }
	|	SETFRQ				{ $$ = servSetFrq; }
	|	SETCHANNEL			{ $$ = servSetChannel; }
	|	SETVOLUME			{ $$ = servSetVolume; }
	|	SETBASS				{ $$ = servSetBass; }
	|	SETTREBLE			{ $$ = servSetTreble; }
	|	SETMUTE				{ $$ = servSetMute; }
	|	TMPMUTE				{ $$ = servTmpMute; }
	|	REFRESHMUTE			{ $$ = servRefreshMute; }
	|	SETVGA				{ $$ = servSetVGA; }
	|	SETTV				{ $$ = servSetTV; }
	|	SETVCR				{ $$ = servSetVCR; }
	|	SETPAL				{ $$ = servSetPAL; }
	|	SETNTSC				{ $$ = servSetNTSC; }
	|	SETHUE				{ $$ = servSetHue; }
	|	SETBRIGHTNESS			{ $$ = servSetBrightness; }
	|	SETSATURATION			{ $$ = servSetSaturation; }
	|	SETCONTRAST			{ $$ = servSetContrast; }
	|	SETRED				{ $$ = servSetRed; }
	|	SETGREEN			{ $$ = servSetGreen; }
	|	SETBLUE				{ $$ = servSetBlue; }
	|	CHANNELNAME			{ $$ = servChannelName; }
	|	ISVISIBLE			{ $$ = servIsVisible; }
	|	ISRADIO				{ $$ = servIsRadio; }
	|	GETTVVCR			{ $$ = servGetTVVCR; }
	|	GETPALNTSC			{ $$ = servGetPALNTSC; }
	|	GETCHANNEL			{ $$ = servGetChannel; }
	|	GETFRQ				{ $$ = servGetFrq; }
	|	GETMUTE				{ $$ = servGetMute; }
	|	GETEXTERNALMUTE			{ $$ = servGetExternalMute; }
	|	GETBASS				{ $$ = servGetBass; }
	|	GETTREBLE			{ $$ = servGetTreble; }
	|	GETVOLUME			{ $$ = servGetVolume; }
	|	GETINTERNALVOLUME		{ $$ = servGetInternalVolume; }
	|	GETEXTERNALVOLUME		{ $$ = servGetExternalVolume; }
	|	GETBRIGHTNESS			{ $$ = servGetBrightness; }
	|	GETSATURATION			{ $$ = servGetSaturation; }
	|	GETCONTRAST			{ $$ = servGetContrast; }
	|	GETHUE				{ $$ = servGetHue; }
	|	GETRED				{ $$ = servGetRed; }
	|	GETGREEN			{ $$ = servGetGreen; }
	|	GETBLUE				{ $$ = servGetBlue; }
	|	CHANNELINFO			{ $$ = servChannelInfo; }
	|	SETCHANNELINFO			{ $$ = servSetChannelInfo; }
	|	CLEARSCREEN			{ $$ = servClearScreen; }
	|	SHOWHELP			{ $$ = servShowHelp; }
	|	SHOWTVVCR			{ $$ = servShowTVVCR; }
	|	SHOWMUTE			{ $$ = servShowMute; }
	|	SHOWBASS			{ $$ = servShowBass; }
	|	SHOWTREBLE			{ $$ = servShowTreble; }
	|	SHOWVOLUME			{ $$ = servShowVolume; }
	|	SHOWCOLOR			{ $$ = servShowColor; }
	|	SHOWCHANNEL			{ $$ = servShowChannel; }
	|	NAME				{ $$ = NULL; }

parms:
						{ $$ = NULL; }
	|	parm				{ $$ = malloc(sizeof(ParmRec));
						  *$$ = $1; $$->next = NULL; }
	|	parm ',' parms			{ $$ = malloc(sizeof(ParmRec));
						  *$$ = $1; $$->next = $3; }

parm:
		NUMBER				{ $$.type = tInt;
						  $$.parm.iParm = $1; }
	|	STRING				{ $$.type = tStr;
						  $$.parm.sParm = $1; }

%%
